@@ -41,27 +41,27 @@ exports.features = (function() {
 
         // We need WebSocket support to even send messages to the server
         if (checks.failed("WebSocket")) {
-            insertError(
-                "WebSockets are not supported");
+            insertError(_(
+                "WebSockets are not supported"));
         }
 
         // We need touch events to simulate touchpad
         if (checks.failed("TouchEvents")) {
-            insertError(
-                "Touch events are not supported");
+            insertError(_(
+                "Touch events are not supported"));
         }
 
         // If any checks failed, add them to the displayed list
         if (list.childNodes.length > 0) {
             var message = document.createDocumentFragment();
-            message.appendChild(document.createTextNode(
+            message.appendChild(document.createTextNode(_(
                 "Your browser does not support Virtual Touchpad. These "
-                + "features are missing:"));
+                + "features are missing:")));
             var ul = document.createElement("ul");
             ul.appendChild(list);
             message.appendChild(ul);
-            message.appendChild(document.createTextNode(
-                "Please upgrade your browser to a newer version."));
+            message.appendChild(document.createTextNode(_(
+                "Please upgrade your browser to a newer version.")));
 
             messagebox.show(
                 message,
